
First of all, **thank you** for considering a contribution to Vulnmine.

Community collaboration and participation is what makes open source work.

## Testing

Tests are automated using the [pytest framework](https://docs.pytest.org/en/latest/). New features should have corresponding test coverage.

Note that we can always use more test coverage!

## Submitting changes

Please send a GitHub Pull Request to Vulnmine with a clear list of what you've done.

For more information on Forking Workflow collaboration, Atlassian has a [tutorial](https://www.atlassian.com/git/tutorials/comparing-workflows#forking-workflow).


Please follow reasonable source coding conventions (e.g. PEP 8, [Hitchhiker's Guide to Python - Coding Style](http://python-guide-pt-br.readthedocs.io/en/latest/writing/style/) ).

Make sure all of your commits are atomic (one feature per commit).

Always write a clear log message for your commits. One-line messages are fine for small changes, but bigger changes should look like this:

```bash
$ git commit -m "A brief summary of the commit"
>
> A paragraph describing what changed and its impact.
>
```

## Contacting us

Issues (bugs, feature requests) can be submitted directly on Github.

The Vulnmine dev team is on [Peerlyst](https://www.peerlyst.com/). Try poking lorgor77.


